---
title: cache
type: output
status: stable
categories: ["Services"]
---

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the contents of:
     lib/output/cache.go
-->

import Tabs from '@theme/Tabs';
import TabItem from '@theme/TabItem';


Stores each message in a [cache](/docs/components/caches/about).


<Tabs defaultValue="common" values={[
  { label: 'Common', value: 'common', },
  { label: 'Advanced', value: 'advanced', },
]}>

<TabItem value="common">

```yaml
# Common config fields, showing default values
output:
  label: ""
  cache:
    target: ""
    key: ${!count("items")}-${!timestamp_unix_nano()}
    max_in_flight: 1
```

</TabItem>
<TabItem value="advanced">

```yaml
# All config fields, showing default values
output:
  label: ""
  cache:
    target: ""
    key: ${!count("items")}-${!timestamp_unix_nano()}
    ttl: ""
    max_in_flight: 1
```

</TabItem>
</Tabs>

Caches are configured as [resources](/docs/components/caches/about) and can target any of the following types:

- [`aws_dynamodb`](/docs/components/caches/aws_dynamodb)
- [`aws_s3`](/docs/components/caches/aws_s3)
- [`dynamodb`](/docs/components/caches/dynamodb)
- [`file`](/docs/components/caches/file)
- [`memcached`](/docs/components/caches/memcached)
- [`memory`](/docs/components/caches/memory)
- [`multilevel`](/docs/components/caches/multilevel)
- [`redis`](/docs/components/caches/redis)
- [`ristretto`](/docs/components/caches/ristretto)
- [`s3`](/docs/components/caches/s3)

The `target` field must point to a configured cache like follows:

```yaml
output:
  cache:
    target: foo
    key: ${!json("document.id")}

cache_resources:
  - label: foo
    memcached:
      addresses:
        - localhost:11211
      ttl: 60
```

In order to create a unique `key` value per item you should use
function interpolations described [here](/docs/configuration/interpolation#bloblang-queries).
When sending batched messages the interpolations are performed per message part.

## Performance

This output benefits from sending multiple messages in flight in parallel for
improved performance. You can tune the max number of in flight messages with the
field `max_in_flight`.

## Fields

### `target`

The target cache to store messages in.


Type: `string`  
Default: `""`  

### `key`

The key to store messages by, function interpolation should be used in order to derive a unique key for each message.
This field supports [interpolation functions](/docs/configuration/interpolation#bloblang-queries).


Type: `string`  
Default: `"${!count(\"items\")}-${!timestamp_unix_nano()}"`  

```yaml
# Examples

key: ${!count("items")}-${!timestamp_unix_nano()}

key: ${!json("doc.id")}

key: ${!meta("kafka_key")}
```

### `ttl`

The TTL of each individual item as a duration string. After this period an item will be eligible for removal during the next compaction. Not all caches support per-key TTLs, and those that do not will fall back to their generally configured TTL setting.
This field supports [interpolation functions](/docs/configuration/interpolation#bloblang-queries).


Type: `string`  
Default: `""`  
Requires version 3.33.0 or newer  

```yaml
# Examples

ttl: 60s

ttl: 5m

ttl: 36h
```

### `max_in_flight`

The maximum number of messages to have in flight at a given time. Increase this to improve throughput.


Type: `int`  
Default: `1`  


